class StreamState:
    created = 'created'
    streaming = 'streaming'
    pending_reconnect = 'pending_reconnect'
    dvr_processing = 'dvr_processing'
    closed = 'closed'
